//
// C++ Interface: CShaderEdit
//
// Description: 
//
//
// Author: Harald Krippel <harald@the-develop.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//

#ifndef CSHADEREDITDLG_H
#define CSHADEREDITDLG_H

/**
  *@author Krippel Harald
  */

#include <QDialog>
#include <QString>
#include <QPixmap>

#include "ui_shaderdlg4.h"
#include "CQcakeDlg.hpp"
#include "listviews.hpp"

class CShaderEditDlg: public CQcakeDlg
{
    Q_OBJECT
      
public:
    CShaderEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
    ~CShaderEditDlg();

public slots:
    virtual void slotGetData();
    virtual void slotGetData(FolderListItem *i);
    virtual void slotEditData();
    virtual void slotEditorScriptv();
    virtual void slotEditorScriptf();
    virtual void slotEditorScript(QString arg);
    virtual void slotGetScriptv();
    virtual void slotGetScriptf();
 
private slots:
 
protected:
    Ui::ShaderEditDlg ui;    
    FolderListItem *point;
    
private:
    QWidget *myParent;
};
#endif
